--- a/jdk/make/netbeans/jmx/build.properties Thu Oct 28 21:14:44 2010 +0800
+++ b/jdk/make/netbeans/jmx/build.properties Fri Oct 29 12:35:07 2010 +0200
@@ -48,8 +48,8 @@
jar.jmx.sealed = true
jar.jmx.spec.title = JSR 003, 160, 255 - JMX API
jar.jmx.spec.version = ${project.spec.version}
-jar.jmx.spec.vendor = Sun Microsystems, Inc.
-jar.jmx.impl.title = JSR 003, 160, 255 - OpenJDK 7 JMX API
+jar.jmx.spec.vendor = Oracle Corporation
+jar.jmx.impl.title = JSR 003, 160, 255 - OpenJDK 7 JMX API
jar.jmx.impl.vendor = Project OpenJDK
javadoc.options=-J-Xmx256m
--- a/jdk/src/share/classes/com/sun/management/package.html Thu Oct 28 21:14:44 2010 +0800
+++ b/jdk/src/share/classes/com/sun/management/package.html Fri Oct 29 12:35:07 2010 +0200
@@ -30,7 +30,7 @@
</head>
<body bgcolor="white">
-This package contains Sun Microsystem's platform extension to
+This package contains Oracle Corporation's platform extension to
the implementation of the
<a href="{@docRoot}/../../../../api/java/lang/management/package-summary.html">
java.lang.management</a> API and also defines the management
--- a/jdk/src/share/classes/javax/management/ObjectName.java Thu Oct 28 21:14:44 2010 +0800
+++ b/jdk/src/share/classes/javax/management/ObjectName.java Fri Oct 29 12:35:07 2010 +0200
@@ -211,8 +211,8 @@
* reverse DNS name of the organization that specifies the MBeans,
* followed by a period and a string whose interpretation is
* determined by that organization. For example, MBeans specified by
- * Sun Microsystems Inc., DNS name <code>sun.com</code>, would have
- * domains such as <code>com.sun.MyDomain</code>. This is essentially
+ * <code>example.com</code> would have
+ * domains such as <code>com.example.MyDomain</code>. This is essentially
* the same convention as for Java-language package names.</p>
*
* <p>The <b>serialVersionUID</b> of this class is <code>1081892073854801359L</code>.
--- a/jdk/src/share/classes/javax/management/build.xml Thu Oct 28 21:14:44 2010 +0800
+++ b/jdk/src/share/classes/javax/management/build.xml Fri Oct 29 12:35:07 2010 +0200
@@ -35,18 +35,18 @@
. Please also read the important comment on basedir definition below.
-->
-<project name="JMX API Version 1.4 - Java SE 6 implementation"
- default="jar"
- basedir="../../../../.."
+<project name="JMX API Version 1.4 - Java SE 6 implementation"
+ default="jar"
+ basedir="../../../../.."
>
- <!-- IMPORTANT: BASEDIR DEFINITION
- This file is assumed to be in:
- <src_bundle_dir>/j2se/src/share/classes/javax/management
- Thus the basedir for this project is defined above as:
- basedir="../../../../.."
+ <!-- IMPORTANT: BASEDIR DEFINITION
+ This file is assumed to be in:
+ <src_bundle_dir>/j2se/src/share/classes/javax/management
+ Thus the basedir for this project is defined above as:
+ basedir="../../../../.."
in order to be the parent dir of src subdir.
- Result of the build will be placed in ${basedir}/build_jmx
+ Result of the build will be placed in ${basedir}/build_jmx
as defined by ${dir.build} property below.
-->
@@ -163,14 +163,14 @@
<echo message=" BUILD_DATE = ${BUILD_DATE}" />
</target>
-
+
<!-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ -->
<!-- Call classes subtargets and rmic stubs generation -->
- <target name="classes" depends="init,classes-javac,classes-rmic"
- description="Call classes subtargets and rmic stubs generation"
+ <target name="classes" depends="init,classes-javac,classes-rmic"
+ description="Call classes subtargets and rmic stubs generation"
/>
@@ -183,13 +183,13 @@
<mkdir dir="${dir.build.classes}" />
<javac srcdir="${dir.src}"
- destdir="${dir.build.classes}"
+ destdir="${dir.build.classes}"
source="${flag.javac.source}"
debug="${flag.debug}"
debuglevel="${flag.debug.level}"
optimize="${flag.optimize}"
includeAntRuntime="no"
- includeJavaRuntime="no"
+ includeJavaRuntime="no"
>
<include name="javax/management/**"/>
<include name="com/sun/jmx/**"/>
@@ -253,7 +253,7 @@
<mkdir dir="${dir.build.lib}" />
- <jar jarfile="${dir.build.lib}/jmx.jar"
+ <jar jarfile="${dir.build.lib}/jmx.jar"
update="true"
>
@@ -269,10 +269,10 @@
<attribute name="Sealed" value="true" />
<attribute name="Specification-Title" value="JMX(TM) API" />
<attribute name="Specification-Version" value="1.4" />
- <attribute name="Specification-Vendor" value="Sun Microsystems, Inc." />
+ <attribute name="Specification-Vendor" value="Oracle Corporation" />
<attribute name="Implementation-Title" value="JMX(TM) API, Java SE 6 implementation" />
- <attribute name="Implementation-Version" value="${BUILD_DATE} rebuild of Mustang JMX sources" />
- <attribute name="Implementation-Vendor" value="Source bundle from Sun Microsystems, Inc. - Customer rebuilt" />
+ <attribute name="Implementation-Version" value="${BUILD_DATE} rebuild of Java SE JMX sources" />
+ <attribute name="Implementation-Vendor" value="Source bundle from Oracle Corporation - Customer rebuilt" />
</section>
</manifest>
</jar>
@@ -295,16 +295,16 @@
<!-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ -->
<!-- Delete build directory and all its contents -->
- <target name="clean-all"
+ <target name="clean-all"
description="Delete build directory and all its contents" >
<delete dir="${dir.build}" />
- </target>
-
-
+ </target>
+
+
<!-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ -->
<!-- Clean all and build everything -->
- <target name="all" depends="clean-all,jar"
+ <target name="all" depends="clean-all,jar"
description="Clean all and build everything" />
--- a/jdk/src/share/classes/javax/management/modelmbean/ModelMBeanNotificationInfo.java Thu Oct 28 21:14:44 2010 +0800
+++ b/jdk/src/share/classes/javax/management/modelmbean/ModelMBeanNotificationInfo.java Fri Oct 29 12:35:07 2010 +0200
@@ -92,8 +92,6 @@
* @since 1.5
*/
-// Sun Microsystems, Sept. 2002: Revisited for JMX 1.2 (DF)
-//
@SuppressWarnings("serial") // serialVersionUID is not constant
public class ModelMBeanNotificationInfo
extends MBeanNotificationInfo
--- a/jdk/src/share/classes/com/sun/jmx/defaults/ServiceName.java Thu Oct 28 21:14:44 2010 +0800
+++ b/jdk/src/share/classes/com/sun/jmx/defaults/ServiceName.java Fri Oct 29 12:35:07 2010 +0200
@@ -76,9 +76,9 @@
/**
* The vendor of the JMX specification implemented by this product.
* <BR>
* The value is <CODE>Sun Microsystems</CODE>.
*/
- public static final String JMX_SPEC_VENDOR = "Sun Microsystems";
+ public static final String JMX_SPEC_VENDOR = "Oracle Corporation";
/**
* The name of this product implementing the JMX specification.
@@ -91,7 +91,7 @@
* The name of the vendor of this product implementing the
* JMX specification.
* <BR>
* The value is <CODE>Sun Microsystems</CODE>.
*/
- public static final String JMX_IMPL_VENDOR = "Sun Microsystems";
+ public static final String JMX_IMPL_VENDOR = "Oracle Corporation";
}
@@ -76,9 +76,9 @@
* The vendor of the JMX specification implemented by this product.
* <BR>
- * The value is <CODE>Sun Microsystems</CODE>.
+ * The value is <CODE>Oracle Corporation</CODE>.
*/
@@ -91,7 +91,7 @@
* JMX specification.
* <BR>
- * The value is <CODE>Sun Microsystems</CODE>.
+ * The value is <CODE>Oracle Corporation</CODE>.
*/
--- a/jdk/src/share/classes/com/sun/jmx/snmp/ServiceName.java Thu Oct 28 21:14:44 2010 +0800
+++ b/jdk/src/share/classes/com/sun/jmx/snmp/ServiceName.java Fri Oct 29 12:35:07 2010 +0200
@@ -27,7 +27,7 @@
/**
* Used for storing default values used by SNMP Runtime services.
* <p><b>This API is a Sun Microsystems internal API and is subject
* to change without notice.</b></p>
*/
public class ServiceName {
@@ -144,16 +144,16 @@
/**
* The vendor of the JMX specification implemented by this product.
* <BR>
* The value is <CODE>Sun Microsystems</CODE>.
*/
- public static final String JMX_SPEC_VENDOR = "Sun Microsystems";
+ public static final String JMX_SPEC_VENDOR = "Oracle Corporation";
/**
* The name of the vendor of this product implementing the JMX specification.
* <BR>
* The value is <CODE>Sun Microsystems</CODE>.
*/
- public static final String JMX_IMPL_VENDOR = "Sun Microsystems";
+ public static final String JMX_IMPL_VENDOR = "Oracle Corporation";
/**
* The build number of the current product version, of the form <CODE>rXX</CODE>.
@@ -27,7 +27,7 @@
/**
* Used for storing default values used by SNMP Runtime services.
- * <p><b>This API is a Sun Microsystems internal API and is subject
+ * <p><b>This API is an Oracle Corporation internal API and is subject
* to change without notice.</b></p>
*/
@@ -144,16 +144,16 @@
* The vendor of the JMX specification implemented by this product.
* <BR>
- * The value is <CODE>Sun Microsystems</CODE>.
+ * The value is <CODE>Oracle Corporation</CODE>.
*/
@@ -144,16 +144,16 @@
* The name of the vendor of this product implementing the JMX specification.
* <BR>
- * The value is <CODE>Sun Microsystems</CODE>.
+ * The value is <CODE>Oracle Corporation</CODE>.
*/